hotspot/src/share/vm/memory/genCollectedHeap.hpp
changeset 30154 39cd4e2ccf1c
parent 30152 5fe1c8494b49
child 30155 a3a254791703
--- a/hotspot/src/share/vm/memory/genCollectedHeap.hpp	Thu Apr 02 16:07:27 2015 +0200
+++ b/hotspot/src/share/vm/memory/genCollectedHeap.hpp	Thu Apr 02 16:08:41 2015 +0200
@@ -26,16 +26,16 @@
 #define SHARE_VM_MEMORY_GENCOLLECTEDHEAP_HPP
 
 #include "gc_implementation/shared/adaptiveSizePolicy.hpp"
+#include "gc_interface/collectedHeap.hpp"
 #include "memory/collectorPolicy.hpp"
 #include "memory/generation.hpp"
-#include "memory/sharedHeap.hpp"
 
 class SubTasksDone;
 class FlexibleWorkGang;
 
 // A "GenCollectedHeap" is a SharedHeap that uses generational
 // collection.  It has two generations, young and old.
-class GenCollectedHeap : public SharedHeap {
+class GenCollectedHeap : public CollectedHeap {
   friend class GenCollectorPolicy;
   friend class Generation;
   friend class DefNewGeneration;
@@ -26,16 +26,16 @@
 class FlexibleWorkGang;
 
-// A "GenCollectedHeap" is a SharedHeap that uses generational
+// A "GenCollectedHeap" is a CollectedHeap that uses generational
 // collection.  It has two generations, young and old.